@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::Plugin::Run::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Dist::Zilla::Plugin::Run::VERSION = '0.014';
+  $Dist::Zilla::Plugin::Run::VERSION = '0.015';
 }
 # ABSTRACT: Run external commands at specific phases of Dist::Zilla
 
@@ -14,7 +14,6 @@ BEGIN {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -23,10 +22,18 @@ Dist::Zilla::Plugin::Run - Run external commands at specific phases of Dist::Zil
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
+  [Run::AfterBuild]
+  run = script/do_this.pl --dir %s --version %s
+  run = script/do_that.pl
+
+  [Run::BeforeBuild]
+  run = script/do_this.pl --version %s
+  run = script/do_that.pl
+
   [Run::BeforeRelease]
   run = script/myapp_before1.pl %s
   run = script/myapp_before2.pl %n %v
@@ -36,9 +43,18 @@ version 0.014
   run = deployer.pl --dir %d --tgz %a --name %n --version %v
 
   [Run::AfterRelease]
-  run = script/myapp_after.pl %s %v
+  run = script/myapp_after.pl --archive %s --version %s
   ; %p can be used as the path separator if you have contributors on a different OS
-  run = script%pmyapp_after.pl %s %v
+  run = script%pmyapp_after.pl --archive %s --version %s
+
+  [Run::AfterRelease / MyAppAfter]
+  run = script/myapp_after.pl --archive %s --version %s
+
+  [Run::Test]
+  run = script/tester.pl --name %n --version %v some_file.ext
+
+  [Run::AfterMint]
+  run = some command %d
 
 =head1 DESCRIPTION
 
@@ -95,3 +111,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
